==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PlacementBindingBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PlacementBindingBuilder extends PlacementBindingFluentImpl<PlacementBindingBuilder> implements VisitableBuilder<PlacementBinding,PlacementBindingBuilder>{
  public PlacementBindingBuilder() {
    this(false);
  }
  public PlacementBindingBuilder(Boolean validationEnabled) {
    this(new PlacementBinding(), validationEnabled);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent) {
    this(fluent, false);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PlacementBinding(), validationEnabled);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent,PlacementBinding instance) {
    this(fluent, instance, false);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent,PlacementBinding instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withPlacementRef(instance.getPlacementRef());
      fluent.withStatus(instance.getStatus());
      fluent.withSubjects(instance.getSubjects());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PlacementBindingBuilder(PlacementBinding instance) {
    this(instance,false);
  }
  public PlacementBindingBuilder(PlacementBinding instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withPlacementRef(instance.getPlacementRef());
      this.withStatus(instance.getStatus());
      this.withSubjects(instance.getSubjects());
    }
    this.validationEnabled = validationEnabled; 
  }
  PlacementBindingFluent<?> fluent;
  Boolean validationEnabled;
  public PlacementBinding build() {
    PlacementBinding buildable = new PlacementBinding(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getPlacementRef(),fluent.getStatus(),fluent.getSubjects());
    return buildable;
  }
  
}

==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PlacementBindingBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PlacementBindingBuilder extends PlacementBindingFluent<PlacementBindingBuilder> implements VisitableBuilder<PlacementBinding,PlacementBindingBuilder>{
  public PlacementBindingBuilder() {
    this(false);
  }
  public PlacementBindingBuilder(Boolean validationEnabled) {
    this(new PlacementBinding(), validationEnabled);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent) {
    this(fluent, false);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PlacementBinding(), validationEnabled);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent,PlacementBinding instance) {
    this(fluent, instance, false);
  }
  public PlacementBindingBuilder(PlacementBindingFluent<?> fluent,PlacementBinding instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PlacementBinding());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withPlacementRef(instance.getPlacementRef());
      fluent.withStatus(instance.getStatus());
      fluent.withSubjects(instance.getSubjects());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withPlacementRef(instance.getPlacementRef());
      fluent.withStatus(instance.getStatus());
      fluent.withSubjects(instance.getSubjects());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PlacementBindingBuilder(PlacementBinding instance) {
    this(instance,false);
  }
  public PlacementBindingBuilder(PlacementBinding instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PlacementBinding());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withPlacementRef(instance.getPlacementRef());
      this.withStatus(instance.getStatus());
      this.withSubjects(instance.getSubjects());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withPlacementRef(instance.getPlacementRef());
      this.withStatus(instance.getStatus());
      this.withSubjects(instance.getSubjects());
    }
    this.validationEnabled = validationEnabled; 
  }
  PlacementBindingFluent<?> fluent;
  Boolean validationEnabled;
  public PlacementBinding build() {
    PlacementBinding buildable = new PlacementBinding(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildPlacementRef(),fluent.buildStatus(),fluent.buildSubjects());
    return buildable;
  }
  
}
